﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Xna_codecamp_v2.Objects;

namespace Xna_codecamp_v2
{
    class AI
    {
        Board board;
        List<Node> pieceList;
        int aip; //AI player ID
        SortedList<Node, int> openList;
        SortedList<Node, int> closedList;
        Random random;

        //Call this method with the reference to a board and then the ID of the computer player from definitions
        public AI(Objects.Board board, int player)
        {
            random = new Random();
            this.board = board;
            pieceList = new List<Node>();
            List<Node> tempList = board.getNodeList();
            this.aip = player;

            foreach (Node n in tempList)
            {
                if (n.getContent() != null)
                    if (n.getContent().player == aip)
                    {
                        pieceList.Add(n);
                    }
            }
        }

        private void refreshPieceList()
        {
            List<Node> tempList = board.getNodeList();

            pieceList.Clear();

            foreach (Node n in tempList)
            {
                if (n.getContent() != null)
                    if (n.getContent().player == aip)
                    {
                        pieceList.Add(n);
                    }
            }
        }

        //Get the recommended move for optimal crushage
        //Returns the x,y of the piece in the [0],[1] and the x,y of the move target in [2],[3]
        public int[] crushPunyHuman()
        {
            refreshPieceList();
            int[] returnValue = null;

            returnValue = goodEats();
            if (returnValue != null)
            {
                Console.WriteLine("Eating with " + returnValue[0] + returnValue[1] + " to " + returnValue[2] + returnValue[3]);
                return returnValue;
            }

            returnValue = runAway();
            if (returnValue != null)
            {
                Console.WriteLine("Escape " + returnValue[0] + returnValue[1] + " to " + returnValue[2] + returnValue[3]);
                return returnValue;
            }
            else
            {
                int piece;
                int move;
                while (true)
                {
                    piece = random.Next(pieceList.Count);
                    move = random.Next(3);
                    try
                    {
                        Node tn = pieceList[piece].getNeighbourList().Values[move];
                        if (tn.type == Definitions.clear && pieceList[piece].getNeighbourList().Values[move].isEmpty())
                            return new int[4] { pieceList[piece].x, pieceList[piece].y, pieceList[piece].getNeighbourList().Values[move].x, pieceList[piece].getNeighbourList().Values[move].y };
                    }
                    catch (Exception)
                    {
                    }
                }
            }
        }

        private int[] runAway()
        {
            //int[] = ownvalue, theirvalue, x, y
            Dictionary<Node, int[]> eatArray = new Dictionary<Node, int[]>();
            int[] returnValue = new int[4];
            Boolean isThreatened = false;

            foreach (Node n in pieceList)
            {
                foreach (Node m in n.getNeighbourList().Values)
                {
                    if (!m.isEmpty())
                    {
                        if (m.getContent().player != aip && m.type != Definitions.water)
                        {
                            //Checking if we are threatened
                            if ((n.getContentType() < m.getContentType() && (m.type != Definitions.elephant && n.type != Definitions.rat)) || (m.getContentType() == Definitions.rat && n.getContentType() == Definitions.elephant))
                            {
                                foreach (Node e in n.getNeighbourList().Values)
                                {
                                    if (e.isEmpty() && (e.type == Definitions.clear || e.type == Definitions.trap))
                                    {
                                        foreach (Node x in e.getNeighbourList().Values)
                                        {
                                            if (!x.isEmpty())
                                            {
                                                if ((n.getContentType() < x.getContentType() && (x.getContentType() != Definitions.elephant && n.getContentType() != Definitions.rat)) || (x.getContentType() == Definitions.rat && n.getContentType() == Definitions.elephant))
                                                {
                                                    isThreatened = true;
                                                }
                                            }
                                        }
                                        if (!isThreatened && !eatArray.ContainsKey(n))
                                            eatArray.Add(n, new int[4] { n.getContentType(), m.getContentType(), e.x, e.y });
                                        else
                                            isThreatened = false;
                                    }
                                }
                            }
                        }
                    }
                }
            }

            if (eatArray.Count == 0)
                return null;

            KeyValuePair<Node, int[]> highest = eatArray.First();

            foreach (KeyValuePair<Node, int[]> e in eatArray)
            {
                if (e.Value[0] > highest.Value[0])
                {
                    highest = e;
                }
            }

            return new int[4] { highest.Key.x, highest.Key.y, highest.Value[2], highest.Value[3] };
        }

        private int[] goodEats()
        {
            //int[] = ownvalue, theirvalue, x, y
            Dictionary<Node, int[]> eatArray = new Dictionary<Node, int[]>();
            int[] returnValue = new int[4];

            foreach (Node n in pieceList)
            {
                foreach (Node m in n.getNeighbourList().Values)
                {
                    if (!m.isEmpty())
                    {
                        if (m.getContent().player != aip && m.type != Definitions.water)
                        {
                            //Checking if we can eat the piece
                            if ((n.getContentType() >= m.getContentType() && !(n.getContentType() == Definitions.elephant && m.getContentType() == Definitions.rat)) || (n.getContentType() == Definitions.rat && m.getContentType() == Definitions.elephant))
                            {
                                if(!eatArray.ContainsKey(n))
                                    eatArray.Add(n, new int[4] { n.getContentType(), m.getContentType(), m.x, m.y });
                            }
                        }
                    }
                }
            }

            if (eatArray.Count == 0)
                return null;

            KeyValuePair<Node, int[]> highest = eatArray.First();

            foreach (KeyValuePair<Node, int[]> e in eatArray)
            {
                if (e.Value[1] > highest.Value[1])
                {
                    highest = e;
                }
            }

            return new int[4] { highest.Key.x, highest.Key.y, highest.Value[2], highest.Value[3] };
        }
    }

}
