#region File Description
//-----------------------------------------------------------------------------
// GameplayScreen.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

#region Using Statements
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
using Xna_codecamp_v2.Objects;
#endregion

namespace Xna_codecamp_v2
{
    /// <summary>
    /// This screen implements the actual game logic. It is just a
    /// placeholder to get the idea across: you'll probably want to
    /// put some more interesting gameplay in here!
    /// </summary>
    class dualPlayGameplayScreen : GameScreen
    {
        #region Fields

        ContentManager content;
        SpriteFont gameFont;


        #endregion

        
        SoundEffect fight, punch, slap, alarm,
             mice, cat, dog, wolf, panther, lion, tiger, ele;
        SoundEffectInstance fightInstance, punchInstance, slapInstance, alarmIn,
             miceIn, catIn, dogIn, wolfIn, pantherIn, lionIn, tigerIn, eleIn;
        Song background;

        Texture2D board_img, cursor1_img,cursor2_img, water_img,trap1,trap2,trap3,trap4,trap5,trap6, nest1, nest2;
        Vector2 board_point = new Vector2(190, 30);
        Vector2 cursor_point1 = new Vector2(193, 33);
        Vector2 cursor_point2 = new Vector2(553,513); 

        GamePadState pg1_keyState = GamePad.GetState(PlayerIndex.One);
        KeyboardState pc1_keyState = Keyboard.GetState();

        GamePadState pg2_keyState = GamePad.GetState(PlayerIndex.Two);
        KeyboardState pc2_keyState = Keyboard.GetState();

        Board board = new Board();
        Node temp_node1,temp_node2;
        GamePiece temp_piece1, temp_piece2;

        //AI inhuman;


        // Create a list of sprites
        private List<Sprite> _listOfSprites = new List<Sprite>();

        private Sprite cat_1, cat_2, dog_1, dog_2, wolf_1, wolf_2, tiger_1, tiger_2,
            lion_1, lion_2, elephant_1, elephant_2, rat_1, rat_2, leopard_1, leopard_2;
            


        // Repeat above for all sprites...



        int temp_x1, temp_y1, result,winner, temp_x2, temp_y2;
        int choose_piece = Definitions.notChoose;

        int gameEnd = Definitions.notStart;

        int turn = Definitions.Player1;


        //KeyboardState pg1_keyState = Keyboard.GetState();

        #region Initialization


        /// <summary>
        /// Constructor.
        /// </summary>
        public dualPlayGameplayScreen()
        {
            TransitionOnTime = TimeSpan.FromSeconds(1.5);
            TransitionOffTime = TimeSpan.FromSeconds(0.5);

            
        }


        /// <summary>
        /// Load graphics content for the game.
        /// </summary>
        public override void LoadContent()
        {
            //inhuman = new AI(board, Definitions.Player2);
            if (content == null)
                content = new ContentManager(ScreenManager.Game.Services, "Content");

            gameFont = content.Load<SpriteFont>("gamefont");



            // A real game would probably have more content than this sample, so
            // it would take longer to load. We simulate that by delaying for a
            // while, giving you a chance to admire the beautiful loading screen.
            

            mice = content.Load<SoundEffect>("sound\\mice");
            cat = content.Load<SoundEffect>("sound\\cat");
            dog = content.Load<SoundEffect>("sound\\dog");
            wolf = content.Load<SoundEffect>("sound\\wolf");
            panther = content.Load<SoundEffect>("sound\\panther");
            lion = content.Load<SoundEffect>("sound\\lion");
            tiger = content.Load<SoundEffect>("sound\\tiger");
            ele = content.Load<SoundEffect>("sound\\elephant");

            miceIn = mice.CreateInstance();
            catIn = cat.CreateInstance();
            dogIn = dog.CreateInstance();
            wolfIn = wolf.CreateInstance();
            pantherIn = panther.CreateInstance();
            lionIn = lion.CreateInstance();
            tigerIn = tiger.CreateInstance();
            eleIn = ele.CreateInstance();

            alarm = content.Load<SoundEffect>("sound\\44737_1082_1383");
            alarmIn = alarm.CreateInstance();
            fight = content.Load<SoundEffect>("sound\\02zd428");
            fightInstance = fight.CreateInstance();
            punch = content.Load<SoundEffect>("sound\\PUNCH");
            punchInstance = punch.CreateInstance();
            slap = content.Load<SoundEffect>("sound\\slap");
            slapInstance = slap.CreateInstance();
            background = content.Load<Song>("sound\\zuma");

            MediaPlayer.Volume = 0.75f;
            MediaPlayer.Play(background);


           

            /*********************************
              Load GamePiece Pic Starts here
             **********************************/

            // TODO: use this.Content to load your game content here

            board_img = content.Load<Texture2D>("board_2");
            cursor1_img = content.Load<Texture2D>("cursor_1");
            cursor2_img = content.Load<Texture2D>("cursor_2");
            water_img = content.Load<Texture2D>("water");
            trap1 = content.Load<Texture2D>("trap");
            trap2 = content.Load<Texture2D>("trap");
            trap3 = content.Load<Texture2D>("trap");
            trap4 = content.Load<Texture2D>("trap");
            trap5 = content.Load<Texture2D>("trap");
            trap6 = content.Load<Texture2D>("trap");

            nest1 = content.Load<Texture2D>("nest");
            nest2 = content.Load<Texture2D>("nest");


            // Setup the fTexture sprite to be alive and give it a texture
            cat_1 = new Sprite(true, content.Load<Texture2D>("cat_1"), board.getCoordi(5, 1), Color.White);
            // Add the sprite to the list
            _listOfSprites.Add(cat_1);

            dog_1 = new Sprite(true, content.Load<Texture2D>("dog_1"), board.getCoordi(1, 1), Color.White);
            _listOfSprites.Add(dog_1);

            tiger_1 = new Sprite(true, content.Load<Texture2D>("tiger_1"), board.getCoordi(6, 0), Color.White);
            _listOfSprites.Add(tiger_1);

            lion_1 = new Sprite(true, content.Load<Texture2D>("lion_1"), board.getCoordi(0, 0), Color.White);
            _listOfSprites.Add(lion_1);

            rat_1 = new Sprite(true, content.Load<Texture2D>("rat_1"), board.getCoordi(0, 2), Color.White);
            _listOfSprites.Add(rat_1);

            leopard_1 = new Sprite(true, content.Load<Texture2D>("leopard_1"), board.getCoordi(2, 2), Color.White);
            _listOfSprites.Add(leopard_1);

            wolf_1 = new Sprite(true, content.Load<Texture2D>("wolf_1"), board.getCoordi(4, 2), Color.White);
            _listOfSprites.Add(wolf_1);

            elephant_1 = new Sprite(true, content.Load<Texture2D>("elephant_1"), board.getCoordi(6, 2), Color.White);
            _listOfSprites.Add(elephant_1);



            cat_2 = new Sprite(true, content.Load<Texture2D>("cat_2"), board.getCoordi(1, 7), Color.White);
            _listOfSprites.Add(cat_2);

            dog_2 = new Sprite(true, content.Load<Texture2D>("dog_2"), board.getCoordi(5, 7), Color.White);
            _listOfSprites.Add(dog_2);

            tiger_2 = new Sprite(true, content.Load<Texture2D>("tiger_2"), board.getCoordi(0, 8), Color.White);
            _listOfSprites.Add(tiger_2);

            lion_2 = new Sprite(true, content.Load<Texture2D>("lion_2"), board.getCoordi(6, 8), Color.White);
            _listOfSprites.Add(lion_2);

            rat_2 = new Sprite(true, content.Load<Texture2D>("rat_2"), board.getCoordi(6, 6), Color.White);
            _listOfSprites.Add(rat_2);

            leopard_2 = new Sprite(true, content.Load<Texture2D>("leopard_2"), board.getCoordi(4, 6), Color.White);
            _listOfSprites.Add(leopard_2);

            wolf_2 = new Sprite(true, content.Load<Texture2D>("wolf_2"), board.getCoordi(2, 6), Color.White);
            _listOfSprites.Add(wolf_2);

            elephant_2 = new Sprite(true, content.Load<Texture2D>("elephant_2"), board.getCoordi(0, 6), Color.White);
            _listOfSprites.Add(elephant_2);


            /*********************************
             Load GamePiece Pic ends here
            **********************************/
             
            // once the load has finished, we use ResetElapsedTime to tell the game's
            // timing mechanism that we have just finished a very long frame, and that
            // it should not try to catch up.
            ScreenManager.Game.ResetElapsedTime();


        }


        /// <summary>
        /// Unload graphics content used by the game.
        /// </summary>
        public override void UnloadContent()
        {
            content.Unload();
        }


        #endregion

        #region Update and Draw


        /// <summary>
        /// Updates the state of the game. This method checks the GameScreen.IsActive
        /// property, so the game will stop updating when the pause menu is active,
        /// or if you tab away to a different application.
        /// </summary>
        public override void Update(GameTime gameTime, bool otherScreenHasFocus,
                                                       bool coveredByOtherScreen)
        {
            base.Update(gameTime, otherScreenHasFocus, coveredByOtherScreen);

            
        }


        /// <summary>
        /// Lets the game respond to player input. Unlike the Update method,
        /// this will only be called when the gameplay screen is active.
        /// </summary>
        public override void HandleInput(InputState input)
        {
            if (input == null)
                throw new ArgumentNullException("input");

            // Look up inputs for the active player profile.
            int playerIndex = (int)ControllingPlayer.Value;

   


            KeyboardState keyboardState = input.CurrentKeyboardStates[playerIndex];
            GamePadState gamePadState = input.CurrentGamePadStates[playerIndex];

            // The game pauses either if the user presses the pause button, or if
            // they unplug the active gamepad. This requires us to keep track of
            // whether a gamepad was ever plugged in, because we don't want to pause
            // on PC if they are playing with a keyboard and have no gamepad at all!
            bool gamePadDisconnected = !gamePadState.IsConnected &&
                                       input.GamePadWasConnected[playerIndex];

            if (input.IsPauseGame(ControllingPlayer) || gamePadDisconnected)
            {
                ScreenManager.AddScreen(new PauseMenuScreen(), ControllingPlayer);
            }
            else
            {

                /*********************************************************************
      
                                 Player1's movement starts here

                 *********************************************************************/

                if (gameEnd != Definitions.End && turn == Definitions.Player1)
                {      // Allows the game to exit
                    if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed ||
                        GamePad.GetState(PlayerIndex.Two).Buttons.Back == ButtonState.Pressed)
                        this.Exit();

                    // move player move the cursor

                    GamePadState cg1_keyState = GamePad.GetState(PlayerIndex.One);
                    KeyboardState cc1_keyState = Keyboard.GetState();

                    GamePadState cg2_keyState = GamePad.GetState(PlayerIndex.Two);
                    KeyboardState cc2_keyState = Keyboard.GetState();

                    //cg1_keyState = Keyboard.GetState();

                    //move to right
                    if ( (cg1_keyState.DPad.Right == ButtonState.Released &&  pg1_keyState.DPad.Right == ButtonState.Pressed) ||               
                        (pg1_keyState.ThumbSticks.Left.X != 1 && cg1_keyState.ThumbSticks.Left.X == 1) ||
                        (cc1_keyState.IsKeyUp(Keys.Right) && pc1_keyState.IsKeyDown(Keys.Right) ) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point1.X < 553)
                        {
                            cursor_point1.X += 60;
                        }
                        else if (choose_piece == Definitions.isChosen && cursor_point1.X < 553)
                        {
                            result = board.game_logic(temp_piece1, board.getSquare(temp_x1 + 1, temp_y1), temp_x1, temp_y1);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 + 1, temp_y1);
                                cursor_point1.X += 60;
                                choose_piece = Definitions.notChoose;

                                turn = Definitions.Player2;
                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1 + 1, temp_y1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 + 1, temp_y1);
                                cursor_point1.X += 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x1 + 1, temp_y1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x1 + 1, temp_y1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();

                                turn = Definitions.Player2;
                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 + 1, temp_y1);
                                cursor_point1.X += 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player1;
                                gameEnd = Definitions.End;

                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }
                    }
                        //move down
                    else if ( (cg1_keyState.DPad.Down == ButtonState.Released &&  pg1_keyState.DPad.Down == ButtonState.Pressed) ||        
                        (pg1_keyState.ThumbSticks.Left.Y != -1 && cg1_keyState.ThumbSticks.Left.Y == -1) ||
                        (cc1_keyState.IsKeyUp(Keys.Down) && pc1_keyState.IsKeyDown(Keys.Down)) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point1.Y < 513)
                        {
                            cursor_point1.Y += 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                            cursor_point1.Y < 513)
                        {



                            result = board.game_logic(temp_piece1, board.getSquare(temp_x1, temp_y1 + 1), temp_x1, temp_y1);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 + 1);
                                cursor_point1.Y += 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player2;


                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1 + 1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 + 1);
                                cursor_point1.Y += 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x1, temp_y1 + 1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x1, temp_y1 + 1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();
                                turn = Definitions.Player2;


                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 + 1);
                                cursor_point1.Y += 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player1;
                                gameEnd = Definitions.End;

                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }


                    }
                        // move up
                    else if ((cg1_keyState.DPad.Up == ButtonState.Released && pg1_keyState.DPad.Up == ButtonState.Pressed) ||         
                        (pg1_keyState.ThumbSticks.Left.Y != 1 && cg1_keyState.ThumbSticks.Left.Y == 1) ||
                        (cc1_keyState.IsKeyUp(Keys.Up) && pc1_keyState.IsKeyDown(Keys.Up)) )
                    {

                        if (choose_piece == Definitions.notChoose && cursor_point1.Y >= 93)
                        {
                            cursor_point1.Y -= 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                            cursor_point1.Y >= 93)
                        {
                            result = board.game_logic(temp_piece1, board.getSquare(temp_x1, temp_y1 - 1), temp_x1, temp_y1);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 - 1);
                                cursor_point1.Y -= 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player2;

                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1 - 1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 - 1);
                                cursor_point1.Y -= 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x1, temp_y1 - 1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x1, temp_y1 - 1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();


                                turn = Definitions.Player2;
                            }
                            else if (result == Definitions.inNest)
                            {

                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1, temp_y1 - 1);
                                cursor_point1.Y -= 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player1;
                                gameEnd = Definitions.End;


                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }


                    }
                        //move left
                    else if ((cg1_keyState.DPad.Left == ButtonState.Released && pg1_keyState.DPad.Left == ButtonState.Pressed) ||        
                        (pg1_keyState.ThumbSticks.Left.X != -1 && cg1_keyState.ThumbSticks.Left.X == -1) ||
                        (cc1_keyState.IsKeyUp(Keys.Left) && pc1_keyState.IsKeyDown(Keys.Left)) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point1.X >= 253)
                        {
                            cursor_point1.X -= 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                           cursor_point1.X >= 253)
                        {
                            result = board.game_logic(temp_piece1, board.getSquare(temp_x1 - 1, temp_y1), temp_x1, temp_y1);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 - 1, temp_y1);
                                cursor_point1.X -= 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player2;

                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi( (temp_x1 - 1), temp_y1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 - 1, temp_y1);
                                cursor_point1.X -= 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi( (temp_x1 - 1), temp_y1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x1 - 1, temp_y1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();
                                turn = Definitions.Player2;


                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x1, temp_y1))).Position = board.getCoordi(temp_x1 - 1, temp_y1);
                                cursor_point1.X -= 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player1;
                                gameEnd = Definitions.End;



                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }

                    }
                        //button A is pressed
                    else if ((cg1_keyState.Buttons.A == ButtonState.Released && pg1_keyState.Buttons.A == ButtonState.Pressed) ||
                        (cc1_keyState.IsKeyUp(Keys.A) && pc1_keyState.IsKeyDown(Keys.A)) )        
                    {
                        temp_x1 = ((int)cursor_point1.X - 193) / 60;
                        temp_y1 = ((int)cursor_point1.Y - 33) / 60;
                        temp_node1 = board.getSquare(temp_x1, temp_y1);
                        temp_piece1 = temp_node1.getContent();
                        if (!temp_node1.isEmpty() && temp_piece1.player == Definitions.Player1)
                        {
                            choose_piece = Definitions.isChosen;
                            switch (temp_node1.getContentType())
                            {
                                case 9: alarmIn.Play(); break;
                                case 10: miceIn.Play(); break;
                                case 11: catIn.Play(); break;
                                case 12: dogIn.Play(); break;
                                case 13: wolfIn.Play(); break;
                                case 14: pantherIn.Play(); break;
                                case 15: lionIn.Play(); break;
                                case 16: tigerIn.Play(); break;
                                case 17: eleIn.Play(); break;
                            }


                        }

                    }


                    pg1_keyState = cg1_keyState;
                    pc1_keyState = cc1_keyState;

                    /*********************************************************************
      
                                        Player1's movement ends here

                    *********************************************************************/
                }
                else if (gameEnd != Definitions.End && turn == Definitions.Player2)
                {

                    /*********************************************************************
      
                                       Player2's movement starts here

                   *********************************************************************/


                   // Allows the game to exit
                    if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed ||
                        GamePad.GetState(PlayerIndex.Two).Buttons.Back == ButtonState.Pressed)
                        this.Exit();

                    // move player move the cursor

                   // GamePadState cg1_keyState = GamePad.GetState(PlayerIndex.One);
                   // KeyboardState cc1_keyState = Keyboard.GetState();

                    GamePadState cg2_keyState = GamePad.GetState(PlayerIndex.Two);
                    KeyboardState cc2_keyState = Keyboard.GetState();

                    //cg1_keyState = Keyboard.GetState();

                    //move to right
                    if ( (cg2_keyState.DPad.Right == ButtonState.Released && pg2_keyState.DPad.Right == ButtonState.Pressed) ||               
                        (pg2_keyState.ThumbSticks.Left.X != 1 && cg2_keyState.ThumbSticks.Left.X == 1) ||
                        (cc2_keyState.IsKeyUp(Keys.Right) && pc2_keyState.IsKeyDown(Keys.Right) ) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point2.X < 553)
                        {
                            cursor_point2.X += 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                            cursor_point2.X < 553)
                        {
                            result = board.game_logic(temp_piece2, board.getSquare(temp_x2 + 1, temp_y2), temp_x2, temp_y2);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 + 1, temp_y2);
                                cursor_point2.X += 60;
                                choose_piece = Definitions.notChoose;

                                turn = Definitions.Player1;
                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2 + 1, temp_y2))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 + 1, temp_y2);
                                cursor_point2.X += 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x2 + 1, temp_y2));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x2 + 1, temp_y2));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();

                                turn = Definitions.Player1;
                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 + 1, temp_y2);
                                cursor_point2.X += 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player2;
                                gameEnd = Definitions.End;

                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }
                    }
                        //move down
                    else if ( (cg2_keyState.DPad.Down == ButtonState.Released &&  pg2_keyState.DPad.Down == ButtonState.Pressed) ||        
                        (pg2_keyState.ThumbSticks.Left.Y != -1 && cg2_keyState.ThumbSticks.Left.Y == -1) ||
                        (cc2_keyState.IsKeyUp(Keys.Down) && pc2_keyState.IsKeyDown(Keys.Down)) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point2.Y < 513)
                        {
                            cursor_point2.Y += 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                            cursor_point2.Y < 513)
                        {



                            result = board.game_logic(temp_piece2, board.getSquare(temp_x2, temp_y2 + 1), temp_x2, temp_y2);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 + 1);
                                cursor_point2.Y += 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player1;


                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2 + 1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 + 1);
                                cursor_point2.Y += 60;
                                choose_piece = Definitions.notChoose;


                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x2, temp_y2 + 1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x2, temp_y2 + 1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();
                                turn = Definitions.Player1;


                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 + 1);
                                cursor_point2.Y += 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player2;
                                gameEnd = Definitions.End;

                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }


                    }
                        // move up
                    else if ((cg2_keyState.DPad.Up == ButtonState.Released && pg2_keyState.DPad.Up == ButtonState.Pressed) ||         
                        (pg2_keyState.ThumbSticks.Left.Y != 1 && cg2_keyState.ThumbSticks.Left.Y == 1) ||
                        (cc2_keyState.IsKeyUp(Keys.Up) && pc2_keyState.IsKeyDown(Keys.Up)) )
                    {

                        if (choose_piece == Definitions.notChoose && cursor_point2.Y >= 93)
                        {
                            cursor_point2.Y -= 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                            cursor_point2.Y >= 93)
                        {
                            result = board.game_logic(temp_piece2, board.getSquare(temp_x2, temp_y2 - 1), temp_x2, temp_y2);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 - 1);
                                cursor_point2.Y -= 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player1;

                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2 - 1))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 - 1);
                                cursor_point2.Y -= 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi(temp_x2, temp_y2 - 1));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x2, temp_y2 - 1));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();
                                turn = Definitions.Player1;
                            }
                            else if (result == Definitions.inNest)
                            {

                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2, temp_y2 - 1);
                                cursor_point2.Y -= 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player2;
                                gameEnd = Definitions.End;


                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }


                    }
                        //move left
                    else if ((cg2_keyState.DPad.Left == ButtonState.Released && pg2_keyState.DPad.Left == ButtonState.Pressed) ||        
                        (pg2_keyState.ThumbSticks.Left.X != -1 && cg2_keyState.ThumbSticks.Left.X == -1) ||
                        (cc2_keyState.IsKeyUp(Keys.Left) && pc2_keyState.IsKeyDown(Keys.Left)) )
                    {
                        if (choose_piece == Definitions.notChoose && cursor_point2.X >= 253)
                        {
                            cursor_point2.X -= 60;
                        }
                        else if (choose_piece == Definitions.isChosen &&
                           cursor_point2.X >= 253)
                        {
                            result = board.game_logic(temp_piece2, board.getSquare(temp_x2 - 1, temp_y2), temp_x2, temp_y2);

                            if (result == Definitions.moved)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 - 1, temp_y2);
                                cursor_point2.X -= 60;
                                choose_piece = Definitions.notChoose;
                                turn = Definitions.Player1;

                            }
                            else if (result == Definitions.killed)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2 - 1, temp_y2))).Alive = false;
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 - 1, temp_y2);
                                cursor_point2.X -= 60;
                                choose_piece = Definitions.notChoose;

                                //add fight animation

                                ScreenManager.game.explosion.AddParticles(board.getCoordi((temp_x2 - 1), temp_y2));
                                ScreenManager.game.smoke.AddParticles(board.getCoordi(temp_x2 - 1, temp_y2));

                                fightInstance.Play();
                                punchInstance.Play();
                                slapInstance.Play();
                                turn = Definitions.Player1;


                            }
                            else if (result == Definitions.inNest)
                            {
                                _listOfSprites.Find(p => p.Position.Equals(board.getCoordi(temp_x2, temp_y2))).Position = board.getCoordi(temp_x2 - 1, temp_y2);
                                cursor_point2.X -= 60;
                                choose_piece = Definitions.notChoose;
                                winner = Definitions.Player2;
                                gameEnd = Definitions.End;



                            }
                            else if (result == Definitions.blocked)
                            {
                                choose_piece = Definitions.notChoose;

                            }
                            else
                            {
                                choose_piece = Definitions.notChoose;

                            }

                        }

                    }
                        //button A is pressed
                    else if ((cg2_keyState.Buttons.A == ButtonState.Released && pg2_keyState.Buttons.A == ButtonState.Pressed) ||
                        (cc2_keyState.IsKeyUp(Keys.A) && pc2_keyState.IsKeyDown(Keys.A)) )        
                    {
                        temp_x2 = ((int)cursor_point2.X - 193) / 60;
                        temp_y2 = ((int)cursor_point2.Y - 33) / 60;
                        temp_node2 = board.getSquare(temp_x2, temp_y2);
                        temp_piece2 = temp_node2.getContent();
                        if (!temp_node2.isEmpty() && temp_piece2.player == Definitions.Player2)
                        {
                            choose_piece = Definitions.isChosen;
                            switch (temp_node2.getContentType())
                            {
                                case 9: alarmIn.Play(); break;
                                case 10: miceIn.Play(); break;
                                case 11: catIn.Play(); break;
                                case 12: dogIn.Play(); break;
                                case 13: wolfIn.Play(); break;
                                case 14: pantherIn.Play(); break;
                                case 15: lionIn.Play(); break;
                                case 16: tigerIn.Play(); break;
                                case 17: eleIn.Play(); break;
                            }


                        }

                    }


                    pg2_keyState = cg2_keyState;
                    pc2_keyState = cc2_keyState;


                    /*********************************************************************
      
                                      Player2's movement ends here

                  *********************************************************************/

                }
                else if (gameEnd == Definitions.End)
                {
                    string ss = null;
                    if (winner == Definitions.Player1)
                        ss = "Player1 is the winner!";
                    else ss = "Player2 is the winner!";

                    LoadingScreen.Load(ScreenManager, false, null, new BackgroundScreen(),
                                                           new WinScreen(ss));
                }

  


             }

        }


        /// <summary>
        /// Draws the gameplay screen.
        /// </summary>
        public override void Draw(GameTime gameTime)
        {
            // This game has a blue background. Why? Because!
            ScreenManager.GraphicsDevice.Clear(ClearOptions.Target,
                                               Color.Black, 0, 0);

            // Our player and enemy are both actually just text strings.
            SpriteBatch spriteBatch = ScreenManager.SpriteBatch;

            spriteBatch.Begin();
            spriteBatch.Draw(board_img, board_point, Color.White);
            spriteBatch.Draw(cursor1_img, cursor_point1, Color.White);
            spriteBatch.Draw(cursor2_img, cursor_point2, Color.White);

            spriteBatch.Draw(nest1, new Vector2(370, 30), Color.White);
            spriteBatch.Draw(nest1, new Vector2(370, 510), Color.White);
            spriteBatch.Draw(water_img, new Vector2(250, 210), Color.White);
            spriteBatch.Draw(water_img, new Vector2(430, 210), Color.White);
            spriteBatch.Draw(cursor1_img, cursor_point1, Color.White);
            spriteBatch.Draw(cursor2_img, cursor_point2, Color.White);
            

            spriteBatch.Draw(trap1, new Vector2(310, 30), Color.White);
            spriteBatch.Draw(trap2, new Vector2(370, 90), Color.White);
            spriteBatch.Draw(trap3, new Vector2(430, 30), Color.White);
            spriteBatch.Draw(trap4, new Vector2(310, 510), Color.White);
            spriteBatch.Draw(trap5, new Vector2(370, 450), Color.White);
            spriteBatch.Draw(trap6, new Vector2(430, 510), Color.White);



            if (gameEnd == Definitions.notStart)
            {
                foreach (Sprite s in _listOfSprites)
                {
                    if (s.Alive)
                        spriteBatch.Draw(s.SpriteTexture, s.Position, s.DrawColor);
                }
                gameEnd = Definitions.Start;
            }
            else if (gameEnd == Definitions.Start)
            {
                foreach (Sprite s in _listOfSprites)
                {
                    if (s.Alive)
                        spriteBatch.Draw(s.SpriteTexture, s.Position, s.DrawColor);
                }

            }
            

            spriteBatch.End();

            // If the game is transitioning on or off, fade it out to black.
            if (TransitionPosition > 0)
                ScreenManager.FadeBackBufferToBlack(255 - TransitionAlpha);
        }


        #endregion
    }
}
